package
Version:
v0.15.1
Opens a new window with list of versions in this module.
Published: Feb 27, 2026
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Namespace struct {
Ns string `json:"ns"`
Path string `json:"path"`
Parent string `json:"parent"`
Ctime int64 `json:"ctime"`
}
Namespace represents a single PBS namespace.
ListNamespaces tries the PBS CLI first and, if it fails,
falls back to the filesystem to infer namespaces.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.