environment

package
v0.13.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DetectProxmoxType

func DetectProxmoxType() types.ProxmoxType

DetectProxmoxType detects whether the system is running Proxmox VE or Proxmox Backup Server

func GetVersion

func GetVersion(pType types.ProxmoxType) (string, error)

GetVersion returns the version string of the detected Proxmox system

Types

type EnvironmentInfo

type EnvironmentInfo struct {
	Type    types.ProxmoxType
	Version string
}

EnvironmentInfo holds information about the current Proxmox environment

func Detect

func Detect() (*EnvironmentInfo, error)

Detect detects the Proxmox environment and returns detailed information

Jump to