package
Version:
v0.12.1
Opens a new window with list of versions in this module.
Published: Jan 1, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Namespace struct {
Ns string `json:"ns"`
Path string `json:"path"`
Parent string `json:"parent"`
Ctime int64 `json:"ctime"`
}
Namespace rappresenta un singolo namespace PBS.
ListNamespaces prova prima a usare la CLI PBS e, se fallisce,
effettua il fallback su filesystem per dedurre i namespace.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.